@@ -6,11 +6,9 @@ library(nlsem)
 
 # ordinary lms
 # ============
-num.classes <- 1
 lms_model <- specify_sem(num.x=6, num.y=3, num.xi=2, num.eta=1,
-                         xi="x1-x3,x4-x6", eta="y1-y3", num.classes,
-                         interaction="xi1:xi2",
-                         interc.obs=FALSE, interc.lat=FALSE)
+                         xi="x1-x3,x4-x6", eta="y1-y3", num.classes=1,
+                         interaction="xi1:xi2")
 as.data.frame(lms_model)
 
 # ordinary lms with different inputs for interaction
@@ -18,23 +16,20 @@ as.data.frame(lms_model)
 # "none"
 # --
 lms_model <- specify_sem(num.x=6, num.y=3, num.xi=2, num.eta=1,
-                         xi="x1-x3,x4-x6", eta="y1-y3", num.classes,
-                         interaction="none",
-                         interc.obs=FALSE, interc.lat=FALSE)
+                         xi="x1-x3,x4-x6", eta="y1-y3", num.classes=1,
+                         interaction="none")
 
 # not all interactions with xi defined
 # ------------------------------------
 lms_model <- specify_sem(num.x=8, num.y=6, num.xi=4, num.eta=3,
                          xi="x1-x2,x3-x4,x5-x6,x7-x8", eta="y1-y2,y3-y4,y5-y6",
-                         num.classes=1, interaction="xi1:xi2,xi1:xi1",
-                         interc.obs=FALSE, interc.lat=FALSE)
+                         num.classes=1, interaction="eta1~xi1:xi2,eta1~xi1:xi1")
 
 # semm model
 # ===========
 semm_model <- specify_sem(num.x=6, num.y=3, num.xi=2, num.eta=1,
                          xi="x1-x3,x4-x6", eta="y1-y3", num.classes=3,
-                         interaction="none",
-                         interc.obs=FALSE, interc.lat=FALSE)
+                         interaction="none")
 
 # ===============================
 # Tests for count_free_parameters
@@ -44,8 +39,7 @@ semm_model <- specify_sem(num.x=6, num.y=3, num.xi=2, num.eta=1,
 # ---
 lms_model <- specify_sem(num.x=6, num.y=3, num.xi=2, num.eta=1,
                          xi="x1-x3,x4-x6", eta="y1-y3", num.classes=1,
-                         interaction="xi1:xi2",
-                         interc.obs=FALSE, interc.lat=FALSE)
+                         interaction="xi1:xi2")
 class(lms_model)
 count_free_parameters(lms_model)
 parameters <- 1:count_free_parameters(lms_model)
@@ -55,27 +49,24 @@ rm(parameters, lms_model)
 # -----
 semm_model <- specify_sem(num.x=6, num.y=3, num.xi=2, num.eta=1,
                          xi="x1-x3,x4-x6", eta="y1-y3", num.classes=3,
-                         interaction="none",
-                         interc.obs=FALSE, interc.lat=FALSE)
+                         interaction="none")
 class(semm_model)
 count_free_parameters(semm_model)
 parameters <- 1:count_free_parameters(semm_model)
 rm(parameters, semm_model)
 
-# semm with relation.lat
+# semm with rel.lat
 # =======================
 semm_model <- specify_sem(num.x=8, num.y=6, num.xi=4, num.eta=3,
                          xi="x1-x2,x3-x4,x5-x6,x7-x8", eta="y1-y2,y3-y4,y5-y6",
-                         num.classes=3, interaction="none", interc.obs=FALSE,
-                         interc.lat=FALSE,
-                         relation.lat="eta1~xi1,eta2~xi2,eta3~xi3+xi4,eta2~eta1+eta3")
+                         num.classes=3, interaction="none",
+                         rel.lat="eta1~xi1,eta2~xi2,eta3~xi3+xi4,eta2~eta1+eta3")
 
 # nsemm
 # -----
 nsemm_model <- specify_sem(num.x=6, num.y=3, num.xi=2, num.eta=1,
                          xi="x1-x3,x4-x6", eta="y1-y3", num.classes=3,
-                         interaction="xi1:xi2",
-                         interc.obs=FALSE, interc.lat=FALSE)
+                         interaction="xi1:xi2")
 class(nsemm_model)
 count_free_parameters(nsemm_model)
 parameters <- 1:count_free_parameters(nsemm_model)
